@@ -73,16 +73,16 @@ def version_of_package(pkg: ModuleType) -> str | None:
     from contextlib import suppress
 
     with suppress(AttributeError):
-        return pkg.__version__  # type: ignore
+        return pkg.__version__
     with suppress(AttributeError):
-        return str(pkg.version)  # type: ignore
+        return str(pkg.version)
     with suppress(AttributeError):
-        return ".".join(map(str, pkg.version_info))  # type: ignore
+        return ".".join(map(str, pkg.version_info))
     return None
 
 
 def get_package_info(
-    pkgs: Iterable[str | tuple[str, Callable[[ModuleType], str | None]]]
+    pkgs: Iterable[str | tuple[str, Callable[[ModuleType], str | None] | None]]
 ) -> dict[str, str | None]:
     """get package versions for the passed required & optional packages"""
 
@@ -105,15 +105,15 @@ def get_package_info(
     return pversions
 
 
-def error_message(scheduler, workers, client, client_name="client"):
+def error_message(scheduler, workers, source, source_name="Client"):
     from distributed.utils import asciitable
 
-    client = client.get("packages") if client else "UNKNOWN"
+    source = source.get("packages") if source else "UNKNOWN"
     scheduler = scheduler.get("packages") if scheduler else "UNKNOWN"
     workers = {k: v.get("packages") if v else "UNKNOWN" for k, v in workers.items()}
 
     packages = set()
-    packages.update(client)
+    packages.update(source)
     packages.update(scheduler)
     for worker in workers:
         packages.update(workers.get(worker))
@@ -128,10 +128,10 @@ def error_message(scheduler, workers, client, client_name="client"):
         if pkg in scheduler_relevant_packages:
             versions.add(scheduler_version)
 
-        client_version = (
-            client.get(pkg, "MISSING") if isinstance(client, dict) else client
+        source_version = (
+            source.get(pkg, "MISSING") if isinstance(source, dict) else source
         )
-        versions.add(client_version)
+        versions.add(source_version)
 
         worker_versions = {
             workers[w].get(pkg, "MISSING")
@@ -148,14 +148,14 @@ def error_message(scheduler, workers, client, client_name="client"):
         elif len(worker_versions) == 0:
             worker_versions = None
 
-        errs.append((pkg, client_version, scheduler_version, worker_versions))
+        errs.append((pkg, source_version, scheduler_version, worker_versions))
         if pkg in notes_mismatch_package.keys():
             notes.append(f"-  {pkg}: {notes_mismatch_package[pkg]}")
 
     out = {"warning": "", "error": ""}
 
     if errs:
-        err_table = asciitable(["Package", client_name, "scheduler", "workers"], errs)
+        err_table = asciitable(["Package", source_name, "Scheduler", "Workers"], errs)
         err_msg = f"Mismatched versions found\n\n{err_table}"
         if notes:
             err_msg += "\nNotes: \n{}".format("\n".join(notes))
